
# Type: gene to gene product relationship_subject




URI: [biolink:gene_to_gene_product_relationship_subject](https://w3id.org/biolink/vocab/gene_to_gene_product_relationship_subject)


## Domain and Range

[GeneToGeneProductRelationship](GeneToGeneProductRelationship.md) ->  <sub>REQ</sub> [Gene](Gene.md)

## Parents

 *  is_a: [sequence feature relationship➞subject](sequence_feature_relationship_subject.md)

## Children


## Used by

 * [GeneToGeneProductRelationship](GeneToGeneProductRelationship.md)
